@@ -192,9 +192,9 @@ def perform_installation(mountpoint):
 			enable_testing = False
 			enable_multilib = False
 
-		if installation.minimal_installation(testing=enable_testing, multilib=enable_multilib):
-			installation.set_locale(archinstall.arguments['sys-language'], archinstall.arguments['sys-encoding'].upper())
-			installation.set_hostname(archinstall.arguments['hostname'])
+		if installation.minimal_installation(
+				testing=enable_testing, multilib=enable_multilib, hostname=archinstall.arguments['hostname'],
+				locales=[f"{archinstall.arguments['sys-language']} {archinstall.arguments['sys-encoding'].upper()}"]):
 			if archinstall.arguments.get('mirror-region') is not None:
 				if archinstall.arguments.get("mirrors", None) is not None:
 					installation.set_mirrors(archinstall.arguments['mirror-region'])  # Set the mirrors in the installation medium
@@ -278,7 +278,7 @@ def perform_installation(mountpoint):
 	archinstall.log(f"Disk states after installing: {archinstall.disk_layouts()}", level=logging.DEBUG)
 
 
-if not (archinstall.check_mirror_reachable() or archinstall.arguments.get('skip-mirror-check', False)):
+if archinstall.arguments.get('skip-mirror-check', False) is False and archinstall.check_mirror_reachable() is False:
 	log_file = os.path.join(archinstall.storage.get('LOG_PATH', None), archinstall.storage.get('LOG_FILE', None))
 	archinstall.log(f"Arch Linux mirrors are not reachable. Please check your internet connection and the log file '{log_file}'.", level=logging.INFO, fg="red")
 	exit(1)
