@@ -1,10 +1,12 @@
 import logging
+import pathlib
 import urllib.error
 import urllib.request
 from typing import Union, Mapping, Iterable, Dict, Any, List
 
 from .general import SysCommand
 from .output import log
+from .storage import storage
 
 def sort_mirrorlist(raw_data :bytes, sort_order=["https", "http"]) -> bytes:
 	"""
@@ -144,16 +146,22 @@ def re_rank_mirrors(
 
 
 def list_mirrors(sort_order :List[str] = ["https", "http"]) -> Dict[str, Any]:
-	url = "https://archlinux.org/mirrorlist/?protocol=https&protocol=http&ip_version=4&ip_version=6&use_mirror_status=on"
 	regions = {}
 
-	try:
-		response = urllib.request.urlopen(url)
-	except urllib.error.URLError as err:
-		log(f'Could not fetch an active mirror-list: {err}', level=logging.WARNING, fg="orange")
-		return regions
+	if storage['arguments']['offline']:
+		with pathlib.Path('/etc/pacman.d/mirrorlist').open('rb') as fh:
+			mirrorlist = fh.read()
+	else:
+		url = "https://archlinux.org/mirrorlist/?protocol=https&protocol=http&ip_version=4&ip_version=6&use_mirror_status=on"
+
+		try:
+			response = urllib.request.urlopen(url)
+		except urllib.error.URLError as err:
+			log(f'Could not fetch an active mirror-list: {err}', level=logging.WARNING, fg="orange")
+			return regions
+
+		mirrorlist = response.read()
 
-	mirrorlist = response.read()
 	if sort_order:
 		mirrorlist = sort_mirrorlist(mirrorlist, sort_order=sort_order)
 
@@ -170,5 +178,10 @@ def list_mirrors(sort_order :List[str] = ["https", "http"]) -> Dict[str, Any]:
 
 			url = line.lstrip('#Server = ')
 			regions[region][url] = True
+		elif line.startswith('Server = '):
+			regions.setdefault(region, {})
+
+			url = line.lstrip('Server = ')
+			regions[region][url] = True
 
 	return regions
