@@ -7,6 +7,7 @@ from .utils import get_password
 from ..menu import Menu
 from ..menu.list_manager import ListManager
 from ..models.users import User
+from ..output import FormattedOutput
 
 if TYPE_CHECKING:
 	_: Any
@@ -18,56 +19,51 @@ class UserList(ListManager):
 	"""
 
 	def __init__(self, prompt: str, lusers: List[User]):
-		"""
-		param: prompt
-		type: str
-		param: lusers dict with the users already defined for the system
-		type: Dict
-		param: sudo. boolean to determine if we handle superusers or users. If None handles both types
-		"""
 		self._actions = [
 			str(_('Add a user')),
 			str(_('Change password')),
 			str(_('Promote/Demote user')),
 			str(_('Delete User'))
 		]
-		super().__init__(prompt, lusers, self._actions, self._actions[0])
+		super().__init__(prompt, lusers, [self._actions[0]], self._actions[1:])
 
 	def reformat(self, data: List[User]) -> Dict[str, User]:
-		return {e.display(): e for e in data}
+		table = FormattedOutput.as_table(data)
+		rows = table.split('\n')
 
-	def action_list(self):
-		active_user = self.target if self.target else None
+		# these are the header rows of the table and do not map to any User obviously
+		# we're adding 2 spaces as prefix because the menu selector '> ' will be put before
+		# the selectable rows so the header has to be aligned
+		display_data = {f'  {rows[0]}': None, f'  {rows[1]}': None}
 
-		if active_user is None:
-			return [self._actions[0]]
-		else:
-			return self._actions[1:]
+		for row, user in zip(rows[2:], data):
+			row = row.replace('|', '\\|')
+			display_data[row] = user
 
-	def exec_action(self, data: List[User]) -> List[User]:
-		if self.target:
-			active_user = self.target
-		else:
-			active_user = None
+		return display_data
 
-		if self.action == self._actions[0]:  # add
+	def selected_action_display(self, user: User) -> str:
+		return user.username
+
+	def handle_action(self, action: str, entry: Optional[User], data: List[User]) -> List[User]:
+		if action == self._actions[0]:  # add
 			new_user = self._add_user()
 			if new_user is not None:
 				# in case a user with the same username as an existing user
 				# was created we'll replace the existing one
 				data = [d for d in data if d.username != new_user.username]
 				data += [new_user]
-		elif self.action == self._actions[1]:  # change password
-			prompt = str(_('Password for user "{}": ').format(active_user.username))
+		elif action == self._actions[1]:  # change password
+			prompt = str(_('Password for user "{}": ').format(entry.username))
 			new_password = get_password(prompt=prompt)
 			if new_password:
-				user = next(filter(lambda x: x == active_user, data), 1)
+				user = next(filter(lambda x: x == entry, data))
 				user.password = new_password
-		elif self.action == self._actions[2]:  # promote/demote
-			user = next(filter(lambda x: x == active_user, data), 1)
+		elif action == self._actions[2]:  # promote/demote
+			user = next(filter(lambda x: x == entry, data))
 			user.sudo = False if user.sudo else True
-		elif self.action == self._actions[3]:  # delete
-			data = [d for d in data if d != active_user]
+		elif action == self._actions[3]:  # delete
+			data = [d for d in data if d != entry]
 
 		return data
 
@@ -77,8 +73,7 @@ class UserList(ListManager):
 		return False
 
 	def _add_user(self) -> Optional[User]:
-		print(_('\nDefine a new user\n'))
-		prompt = str(_('Enter username (leave blank to skip): '))
+		prompt = '\n\n' + str(_('Enter username (leave blank to skip): '))
 
 		while True:
 			username = input(prompt).strip(' ')
@@ -94,7 +89,9 @@ class UserList(ListManager):
 		choice = Menu(
 			str(_('Should "{}" be a superuser (sudo)?')).format(username), Menu.yes_no(),
 			skip=False,
-			default_option=Menu.no()
+			default_option=Menu.no(),
+			clear_screen=False,
+			show_search_hint=False
 		).run()
 
 		sudo = True if choice.value == Menu.yes() else False
@@ -102,6 +99,5 @@ class UserList(ListManager):
 
 
 def ask_for_additional_users(prompt: str = '', defined_users: List[User] = []) -> List[User]:
-	prompt = prompt if prompt else _('Enter username (leave blank to skip): ')
 	users = UserList(prompt, defined_users).run()
 	return users
