@@ -12,7 +12,7 @@ __packages__ = [
 	"ark",
 	"sddm",
 	"plasma-wayland-session",
-	"egl-wayland",
+	"egl-wayland"
 ]
 
 
